@@ -1,7 +1,7 @@
 #ifndef MADNESS_H
 #define MADNESS_H
 
-#include <plugin.h>
+#include <noatun/plugin.h>
 #include <string.h>
 #include <qmap.h>
 #include <qvaluelist.h>
